<?php

namespace Events\Events\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Events\Events\Http\Requests\EventsRequest;
use Events\Events\Interfaces\EventsRepositoryInterface;
use Events\Events\Models\Events;

/**
 * Resource controller class for events.
 */
class EventsResourceController extends BaseController
{

    /**
     * Initialize events resource controller.
     *
     * @param type EventsRepositoryInterface $events
     *
     * @return null
     */
    public function __construct(EventsRepositoryInterface $events)
    {
        parent::__construct();
        $this->repository = $events;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Events\Events\Repositories\Criteria\EventsResourceCriteria::class);
    }

    /**
     * Display a list of events.
     *
     * @return Response
     */
    public function index(EventsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Events\Events\Repositories\Presenter\EventsPresenter::class)
                ->$function();
        }

        $events = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('events::events.names'))
            ->view('events::events.index', true)
            ->data(compact('events', 'view'))
            ->output();
    }

    /**
     * Display events.
     *
     * @param Request $request
     * @param Model   $events
     *
     * @return Response
     */
    public function show(EventsRequest $request, Events $events)
    {

        if ($events->exists) {
            $view = 'events::events.show';
        } else {
            $view = 'events::events.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('events::events.name'))
            ->data(compact('events'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new events.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(EventsRequest $request)
    {

        $events = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('events::events.name')) 
            ->view('events::events.create', true) 
            ->data(compact('events'))
            ->output();
    }

    /**
     * Create new events.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EventsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $events                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('events::events.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('events/events/' . $events->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/events/events'))
                ->redirect();
        }

    }

    /**
     * Show events for editing.
     *
     * @param Request $request
     * @param Model   $events
     *
     * @return Response
     */
    public function edit(EventsRequest $request, Events $events)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('events::events.name'))
            ->view('events::events.edit', true)
            ->data(compact('events'))
            ->output();
    }

    /**
     * Update the events.
     *
     * @param Request $request
     * @param Model   $events
     *
     * @return Response
     */
    public function update(EventsRequest $request, Events $events)
    {
        try {
            $attributes = $request->all();

            $events->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('events::events.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('events/events/' . $events->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('events/events/' . $events->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the events.
     *
     * @param Model   $events
     *
     * @return Response
     */
    public function destroy(EventsRequest $request, Events $events)
    {
        try {

            $events->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('events::events.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('events/events/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('events/events/' . $events->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple events.
     *
     * @param Model   $events
     *
     * @return Response
     */
    public function delete(EventsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('events::events.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('events/events'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/events/events'))
                ->redirect();
        }

    }

    /**
     * Restore deleted events.
     *
     * @param Model   $events
     *
     * @return Response
     */
    public function restore(EventsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('events::events.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/events/events'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/events/events/'))
                ->redirect();
        }

    }

}
